django\_opt\_out package
========================

Subpackages
-----------

.. toctree::

    django_opt_out.migrations
    django_opt_out.plugins

Submodules
----------

django\_opt\_out\.admin module
------------------------------

.. automodule:: django_opt_out.admin
    :members:
    :undoc-members:
    :show-inheritance:

django\_opt\_out\.app\_settings module
--------------------------------------

.. automodule:: django_opt_out.app_settings
    :members:
    :undoc-members:
    :show-inheritance:

django\_opt\_out\.apps module
-----------------------------

.. automodule:: django_opt_out.apps
    :members:
    :undoc-members:
    :show-inheritance:

django\_opt\_out\.cli module
----------------------------

.. automodule:: django_opt_out.cli
    :members:
    :undoc-members:
    :show-inheritance:

django\_opt\_out\.factories module
----------------------------------

.. automodule:: django_opt_out.factories
    :members:
    :undoc-members:
    :show-inheritance:

django\_opt\_out\.forms module
------------------------------

.. automodule:: django_opt_out.forms
    :members:
    :undoc-members:
    :show-inheritance:

django\_opt\_out\.models module
-------------------------------

.. automodule:: django_opt_out.models
    :members:
    :undoc-members:
    :show-inheritance:

django\_opt\_out\.resources module
----------------------------------

.. automodule:: django_opt_out.resources
    :members:
    :undoc-members:
    :show-inheritance:

django\_opt\_out\.signals module
--------------------------------

.. automodule:: django_opt_out.signals
    :members:
    :undoc-members:
    :show-inheritance:

django\_opt\_out\.urls module
-----------------------------

.. automodule:: django_opt_out.urls
    :members:
    :undoc-members:
    :show-inheritance:

django\_opt\_out\.utils module
------------------------------

.. automodule:: django_opt_out.utils
    :members:
    :undoc-members:
    :show-inheritance:

django\_opt\_out\.views module
------------------------------

.. automodule:: django_opt_out.views
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: django_opt_out
    :members:
    :undoc-members:
    :show-inheritance:
